Class: KML::Container

Inherits:
Feature show all
Defined in:
lib/kml/container.rb

Overview

A Container is an abstract base class that holds one or more Features and allows the creation of nested hierarchies.

Direct Known Subclasses

Document, Folder, Geometry, Placemark

Instance Attribute Summary collapse

Attributes inherited from Feature

#address, #address_details, #description, #look_at, #metadata, #name, #phone_number, #region, #snippet, #style_selector, #style_url, #time_primitive

Attributes inherited from Object

#id

Method Summary

Methods inherited from Feature

#open, #open=, #open?, #render, #visibility, #visibility=, #visibility?

Methods inherited from Object

#initialize

Constructor Details

This class inherits a constructor from KML::Object

Instance Attribute Details

#featuresObject

Get the features in the container



6
7
8
# File 'lib/kml/container.rb', line 6

def features
  @features
end

#plain_childrenObject

Returns the value of attribute plain_children.



7
8
9
# File 'lib/kml/container.rb', line 7

def plain_children
  @plain_children
end